==> vtk6-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkLightKit.java <==
// java wrapper for vtkLightKit object
//

package vtk;
import vtk.*;

public class vtkLightKit extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetKeyLightIntensity_2(double id0);
  public void SetKeyLightIntensity(double id0)
    { SetKeyLightIntensity_2(id0); }

  private native double GetKeyLightIntensity_3();
  public double GetKeyLightIntensity()
    { return GetKeyLightIntensity_3(); }

  private native void SetKeyToFillRatio_4(double id0);
  public void SetKeyToFillRatio(double id0)
    { SetKeyToFillRatio_4(id0); }

  private native double GetKeyToFillRatioMinValue_5();
  public double GetKeyToFillRatioMinValue()
    { return GetKeyToFillRatioMinValue_5(); }

  private native double GetKeyToFillRatioMaxValue_6();
  public double GetKeyToFillRatioMaxValue()
    { return GetKeyToFillRatioMaxValue_6(); }

  private native double GetKeyToFillRatio_7();
  public double GetKeyToFillRatio()
    { return GetKeyToFillRatio_7(); }

  private native void SetKeyToHeadRatio_8(double id0);
  public void SetKeyToHeadRatio(double id0)
    { SetKeyToHeadRatio_8(id0); }

  private native double GetKeyToHeadRatioMinValue_9();
  public double GetKeyToHeadRatioMinValue()
    { return GetKeyToHeadRatioMinValue_9(); }

  private native double GetKeyToHeadRatioMaxValue_10();
  public double GetKeyToHeadRatioMaxValue()
    { return GetKeyToHeadRatioMaxValue_10(); }

  private native double GetKeyToHeadRatio_11();
  public double GetKeyToHeadRatio()
    { return GetKeyToHeadRatio_11(); }

  private native void SetKeyToBackRatio_12(double id0);
  public void SetKeyToBackRatio(double id0)
    { SetKeyToBackRatio_12(id0); }

  private native double GetKeyToBackRatioMinValue_13();
  public double GetKeyToBackRatioMinValue()
    { return GetKeyToBackRatioMinValue_13(); }

  private native double GetKeyToBackRatioMaxValue_14();
  public double GetKeyToBackRatioMaxValue()
    { return GetKeyToBackRatioMaxValue_14(); }

  private native double GetKeyToBackRatio_15();
  public double GetKeyToBackRatio()
    { return GetKeyToBackRatio_15(); }

  private native void SetKeyLightWarmth_16(double id0);
  public void SetKeyLightWarmth(double id0)
    { SetKeyLightWarmth_16(id0); }

  private native double GetKeyLightWarmth_17();
  public double GetKeyLightWarmth()
    { return GetKeyLightWarmth_17(); }

  private native void SetFillLightWarmth_18(double id0);
  public void SetFillLightWarmth(double id0)
    { SetFillLightWarmth_18(id0); }

  private native double GetFillLightWarmth_19();
  public double GetFillLightWarmth()
    { return GetFillLightWarmth_19(); }

  private native void SetHeadLightWarmth_20(double id0);
  public void SetHeadLightWarmth(double id0)
    { SetHeadLightWarmth_20(id0); }

  private native double GetHeadLightWarmth_21();
  public double GetHeadLightWarmth()
    { return GetHeadLightWarmth_21(); }

  private native void SetBackLightWarmth_22(double id0);
  public void SetBackLightWarmth(double id0)
    { SetBackLightWarmth_22(id0); }

  private native double GetBackLightWarmth_23();
  public double GetBackLightWarmth()
    { return GetBackLightWarmth_23(); }

  private native double[] GetKeyLightColor_24();
  public double[] GetKeyLightColor()
    { return GetKeyLightColor_24(); }

  private native double[] GetFillLightColor_25();
  public double[] GetFillLightColor()
    { return GetFillLightColor_25(); }

  private native double[] GetHeadLightColor_26();
  public double[] GetHeadLightColor()
    { return GetHeadLightColor_26(); }

  private native double[] GetBackLightColor_27();
  public double[] GetBackLightColor()
    { return GetBackLightColor_27(); }

  private native void MaintainLuminanceOn_28();
  public void MaintainLuminanceOn()
    { MaintainLuminanceOn_28(); }

  private native void MaintainLuminanceOff_29();
  public void MaintainLuminanceOff()
    { MaintainLuminanceOff_29(); }

  private native int GetMaintainLuminance_30();
  public int GetMaintainLuminance()
    { return GetMaintainLuminance_30(); }

  private native void SetMaintainLuminance_31(int id0);
  public void SetMaintainLuminance(int id0)
    { SetMaintainLuminance_31(id0); }

  private native void SetKeyLightAngle_32(double id0,double id1);
  public void SetKeyLightAngle(double id0,double id1)
    { SetKeyLightAngle_32(id0,id1); }

  private native void SetKeyLightAngle_33(double id0[]);
  public void SetKeyLightAngle(double id0[])
    { SetKeyLightAngle_33(id0); }

  private native void SetKeyLightElevation_34(double id0);
  public void SetKeyLightElevation(double id0)
    { SetKeyLightElevation_34(id0); }

  private native void SetKeyLightAzimuth_35(double id0);
  public void SetKeyLightAzimuth(double id0)
    { SetKeyLightAzimuth_35(id0); }

  private native double[] GetKeyLightAngle_36();
  public double[] GetKeyLightAngle()
    { return GetKeyLightAngle_36(); }

  private native double GetKeyLightElevation_37();
  public double GetKeyLightElevation()
    { return GetKeyLightElevation_37(); }

  private native double GetKeyLightAzimuth_38();
  public double GetKeyLightAzimuth()
    { return GetKeyLightAzimuth_38(); }

  private native void SetFillLightAngle_39(double id0,double id1);
  public void SetFillLightAngle(double id0,double id1)
    { SetFillLightAngle_39(id0,id1); }

  private native void SetFillLightAngle_40(double id0[]);
  public void SetFillLightAngle(double id0[])
    { SetFillLightAngle_40(id0); }

  private native void SetFillLightElevation_41(double id0);
  public void SetFillLightElevation(double id0)
    { SetFillLightElevation_41(id0); }

  private native void SetFillLightAzimuth_42(double id0);
  public void SetFillLightAzimuth(double id0)
    { SetFillLightAzimuth_42(id0); }

  private native double[] GetFillLightAngle_43();
  public double[] GetFillLightAngle()
    { return GetFillLightAngle_43(); }

  private native double GetFillLightElevation_44();
  public double GetFillLightElevation()
    { return GetFillLightElevation_44(); }

  private native double GetFillLightAzimuth_45();
  public double GetFillLightAzimuth()
    { return GetFillLightAzimuth_45(); }

  private native void SetBackLightAngle_46(double id0,double id1);
  public void SetBackLightAngle(double id0,double id1)
    { SetBackLightAngle_46(id0,id1); }

  private native void SetBackLightAngle_47(double id0[]);
  public void SetBackLightAngle(double id0[])
    { SetBackLightAngle_47(id0); }

  private native void SetBackLightElevation_48(double id0);
  public void SetBackLightElevation(double id0)
    { SetBackLightElevation_48(id0); }

  private native void SetBackLightAzimuth_49(double id0);
  public void SetBackLightAzimuth(double id0)
    { SetBackLightAzimuth_49(id0); }

  private native double[] GetBackLightAngle_50();
  public double[] GetBackLightAngle()
    { return GetBackLightAngle_50(); }

  private native double GetBackLightElevation_51();
  public double GetBackLightElevation()
    { return GetBackLightElevation_51(); }

  private native double GetBackLightAzimuth_52();
  public double GetBackLightAzimuth()
    { return GetBackLightAzimuth_52(); }

  private native void AddLightsToRenderer_53(vtkRenderer id0);
  public void AddLightsToRenderer(vtkRenderer id0)
    { AddLightsToRenderer_53(id0); }

  private native void RemoveLightsFromRenderer_54(vtkRenderer id0);
  public void RemoveLightsFromRenderer(vtkRenderer id0)
    { RemoveLightsFromRenderer_54(id0); }

  private native void DeepCopy_55(vtkLightKit id0);
  public void DeepCopy(vtkLightKit id0)
    { DeepCopy_55(id0); }

  private native void Modified_56();
  public void Modified()
    { Modified_56(); }

  private native void Update_57();
  public void Update()
    { Update_57(); }

  private native String GetStringFromType_58(int id0);
  public String GetStringFromType(int id0)
    { return GetStringFromType_58(id0); }

  private native String GetStringFromSubType_59(int id0);
  public String GetStringFromSubType(int id0)
    { return GetStringFromSubType_59(id0); }

  private native String GetShortStringFromSubType_60(int id0);
  public String GetShortStringFromSubType(int id0)
    { return GetShortStringFromSubType_60(id0); }

  private native int GetSubType_61(int id0,int id1);
  public int GetSubType(int id0,int id1)
    { return GetSubType_61(id0,id1); }

  public vtkLightKit() { super(); }

  public vtkLightKit(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv7h.pkg.tar.xz: vtk/vtkLightKit.java <==
// java wrapper for vtkLightKit object
//

package vtk;
import vtk.*;

public class vtkLightKit extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetKeyLightIntensity_2(double id0);
  public void SetKeyLightIntensity(double id0)
    { SetKeyLightIntensity_2(id0); }

  private native double GetKeyLightIntensity_3();
  public double GetKeyLightIntensity()
    { return GetKeyLightIntensity_3(); }

  private native void SetKeyToFillRatio_4(double id0);
  public void SetKeyToFillRatio(double id0)
    { SetKeyToFillRatio_4(id0); }

  private native double GetKeyToFillRatioMinValue_5();
  public double GetKeyToFillRatioMinValue()
    { return GetKeyToFillRatioMinValue_5(); }

  private native double GetKeyToFillRatioMaxValue_6();
  public double GetKeyToFillRatioMaxValue()
    { return GetKeyToFillRatioMaxValue_6(); }

  private native double GetKeyToFillRatio_7();
  public double GetKeyToFillRatio()
    { return GetKeyToFillRatio_7(); }

  private native void SetKeyToHeadRatio_8(double id0);
  public void SetKeyToHeadRatio(double id0)
    { SetKeyToHeadRatio_8(id0); }

  private native double GetKeyToHeadRatioMinValue_9();
  public double GetKeyToHeadRatioMinValue()
    { return GetKeyToHeadRatioMinValue_9(); }

  private native double GetKeyToHeadRatioMaxValue_10();
  public double GetKeyToHeadRatioMaxValue()
    { return GetKeyToHeadRatioMaxValue_10(); }

  private native double GetKeyToHeadRatio_11();
  public double GetKeyToHeadRatio()
    { return GetKeyToHeadRatio_11(); }

  private native void SetKeyToBackRatio_12(double id0);
  public void SetKeyToBackRatio(double id0)
    { SetKeyToBackRatio_12(id0); }

  private native double GetKeyToBackRatioMinValue_13();
  public double GetKeyToBackRatioMinValue()
    { return GetKeyToBackRatioMinValue_13(); }

  private native double GetKeyToBackRatioMaxValue_14();
  public double GetKeyToBackRatioMaxValue()
    { return GetKeyToBackRatioMaxValue_14(); }

  private native double GetKeyToBackRatio_15();
  public double GetKeyToBackRatio()
    { return GetKeyToBackRatio_15(); }

  private native void SetKeyLightWarmth_16(double id0);
  public void SetKeyLightWarmth(double id0)
    { SetKeyLightWarmth_16(id0); }

  private native double GetKeyLightWarmth_17();
  public double GetKeyLightWarmth()
    { return GetKeyLightWarmth_17(); }

  private native void SetFillLightWarmth_18(double id0);
  public void SetFillLightWarmth(double id0)
    { SetFillLightWarmth_18(id0); }

  private native double GetFillLightWarmth_19();
  public double GetFillLightWarmth()
    { return GetFillLightWarmth_19(); }

  private native void SetHeadLightWarmth_20(double id0);
  public void SetHeadLightWarmth(double id0)
    { SetHeadLightWarmth_20(id0); }

  private native double GetHeadLightWarmth_21();
  public double GetHeadLightWarmth()
    { return GetHeadLightWarmth_21(); }

  private native void SetBackLightWarmth_22(double id0);
  public void SetBackLightWarmth(double id0)
    { SetBackLightWarmth_22(id0); }

  private native double GetBackLightWarmth_23();
  public double GetBackLightWarmth()
    { return GetBackLightWarmth_23(); }

  private native double[] GetKeyLightColor_24();
  public double[] GetKeyLightColor()
    { return GetKeyLightColor_24(); }

  private native double[] GetFillLightColor_25();
  public double[] GetFillLightColor()
    { return GetFillLightColor_25(); }

  private native double[] GetHeadLightColor_26();
  public double[] GetHeadLightColor()
    { return GetHeadLightColor_26(); }

  private native double[] GetBackLightColor_27();
  public double[] GetBackLightColor()
    { return GetBackLightColor_27(); }

  private native void MaintainLuminanceOn_28();
  public void MaintainLuminanceOn()
    { MaintainLuminanceOn_28(); }

  private native void MaintainLuminanceOff_29();
  public void MaintainLuminanceOff()
    { MaintainLuminanceOff_29(); }

  private native int GetMaintainLuminance_30();
  public int GetMaintainLuminance()
    { return GetMaintainLuminance_30(); }

  private native void SetMaintainLuminance_31(int id0);
  public void SetMaintainLuminance(int id0)
    { SetMaintainLuminance_31(id0); }

  private native void SetKeyLightAngle_32(double id0,double id1);
  public void SetKeyLightAngle(double id0,double id1)
    { SetKeyLightAngle_32(id0,id1); }

  private native void SetKeyLightAngle_33(double id0[]);
  public void SetKeyLightAngle(double id0[])
    { SetKeyLightAngle_33(id0); }

  private native void SetKeyLightElevation_34(double id0);
  public void SetKeyLightElevation(double id0)
    { SetKeyLightElevation_34(id0); }

  private native void SetKeyLightAzimuth_35(double id0);
  public void SetKeyLightAzimuth(double id0)
    { SetKeyLightAzimuth_35(id0); }

  private native double[] GetKeyLightAngle_36();
  public double[] GetKeyLightAngle()
    { return GetKeyLightAngle_36(); }

  private native double GetKeyLightElevation_37();
  public double GetKeyLightElevation()
    { return GetKeyLightElevation_37(); }

  private native double GetKeyLightAzimuth_38();
  public double GetKeyLightAzimuth()
    { return GetKeyLightAzimuth_38(); }

  private native void SetFillLightAngle_39(double id0,double id1);
  public void SetFillLightAngle(double id0,double id1)
    { SetFillLightAngle_39(id0,id1); }

  private native void SetFillLightAngle_40(double id0[]);
  public void SetFillLightAngle(double id0[])
    { SetFillLightAngle_40(id0); }

  private native void SetFillLightElevation_41(double id0);
  public void SetFillLightElevation(double id0)
    { SetFillLightElevation_41(id0); }

  private native void SetFillLightAzimuth_42(double id0);
  public void SetFillLightAzimuth(double id0)
    { SetFillLightAzimuth_42(id0); }

  private native double[] GetFillLightAngle_43();
  public double[] GetFillLightAngle()
    { return GetFillLightAngle_43(); }

  private native double GetFillLightElevation_44();
  public double GetFillLightElevation()
    { return GetFillLightElevation_44(); }

  private native double GetFillLightAzimuth_45();
  public double GetFillLightAzimuth()
    { return GetFillLightAzimuth_45(); }

  private native void SetBackLightAngle_46(double id0,double id1);
  public void SetBackLightAngle(double id0,double id1)
    { SetBackLightAngle_46(id0,id1); }

  private native void SetBackLightAngle_47(double id0[]);
  public void SetBackLightAngle(double id0[])
    { SetBackLightAngle_47(id0); }

  private native void SetBackLightElevation_48(double id0);
  public void SetBackLightElevation(double id0)
    { SetBackLightElevation_48(id0); }

  private native void SetBackLightAzimuth_49(double id0);
  public void SetBackLightAzimuth(double id0)
    { SetBackLightAzimuth_49(id0); }

  private native double[] GetBackLightAngle_50();
  public double[] GetBackLightAngle()
    { return GetBackLightAngle_50(); }

  private native double GetBackLightElevation_51();
  public double GetBackLightElevation()
    { return GetBackLightElevation_51(); }

  private native double GetBackLightAzimuth_52();
  public double GetBackLightAzimuth()
    { return GetBackLightAzimuth_52(); }

  private native void AddLightsToRenderer_53(vtkRenderer id0);
  public void AddLightsToRenderer(vtkRenderer id0)
    { AddLightsToRenderer_53(id0); }

  private native void RemoveLightsFromRenderer_54(vtkRenderer id0);
  public void RemoveLightsFromRenderer(vtkRenderer id0)
    { RemoveLightsFromRenderer_54(id0); }

  private native void DeepCopy_55(vtkLightKit id0);
  public void DeepCopy(vtkLightKit id0)
    { DeepCopy_55(id0); }

  private native void Modified_56();
  public void Modified()
    { Modified_56(); }

  private native void Update_57();
  public void Update()
    { Update_57(); }

  private native String GetStringFromType_58(int id0);
  public String GetStringFromType(int id0)
    { return GetStringFromType_58(id0); }

  private native String GetStringFromSubType_59(int id0);
  public String GetStringFromSubType(int id0)
    { return GetStringFromSubType_59(id0); }

  private native String GetShortStringFromSubType_60(int id0);
  public String GetShortStringFromSubType(int id0)
    { return GetShortStringFromSubType_60(id0); }

  private native int GetSubType_61(int id0,int id1);
  public int GetSubType(int id0,int id1)
    { return GetSubType_61(id0,id1); }

  public vtkLightKit() { super(); }

  public vtkLightKit(long id) { super(id); }
  public native long   VTKInit();

}
